@@ -6,6 +6,7 @@ use crate::{
 use cursive::{
     direction::Absolute,
     event::{Callback, Event, EventResult, Key},
+    view::CannotFocus,
     Rect, Vec2, View,
 };
 
@@ -56,7 +57,7 @@ impl ArticleView {
         }
 
         // get the position of the current link and the top of the viewport
-        let link_pos = self.content.current_link_pos().unwrap(); // we can use unwrap here because the feature is enabled
+        let link_pos = self.content.current_link_pos().unwrap_or_default();
         let viewport_top = self.viewport_offset.get();
 
         // if the link is above the viewport (aka its y-pos is smaller than the viewport offset),
@@ -174,9 +175,9 @@ impl View for ArticleView {
         self.content.required_size(constraint)
     }
 
-    fn take_focus(&mut self, _: cursive::direction::Direction) -> bool {
+    fn take_focus(&mut self, _: cursive::direction::Direction) -> Result<EventResult, CannotFocus> {
         // this view is always focusable
-        true
+        Ok(EventResult::Consumed(None))
     }
 
     fn important_area(&self, _: Vec2) -> cursive::Rect {
