@@ -1,5 +1,3 @@
-use crate::wiki::search::SearchResult;
-
 #[derive(Clone)]
 pub struct ArticleResultPreview {
     pub page_id: i32,
@@ -13,16 +11,6 @@ pub struct Article {
     pub content: String,
 }
 
-impl From<SearchResult> for ArticleResultPreview {
-    fn from(search_result: SearchResult) -> Self {
-        ArticleResultPreview {
-            page_id: search_result.page_id,
-            snippet: search_result.snippet,
-            title: search_result.title,
-        }
-    }
-}
-
 impl From<i32> for ArticleResultPreview {
     fn from(page_id: i32) -> Self {
         ArticleResultPreview {
